@@ -41,6 +41,7 @@ from .shapes import (
 )
 
 from openpyxl.descriptors.excel import ExtensionList as OfficeArtExtensionList
+from openpyxl.descriptors.nested import NestedBool
 
 
 class EmbeddedWAVAudioFile(Serialisable):
@@ -117,7 +118,7 @@ class CharacterProperties(Serialisable):
     kumimoji = Bool(allow_none=True)
     lang = String(allow_none=True)
     altLang = String(allow_none=True)
-    sz = Integer()
+    sz = Integer(allow_none=True)
     b = Bool(allow_none=True)
     i = Bool(allow_none=True)
     u = NoneSet(values=(['words', 'sng', 'dbl', 'heavy', 'dotted',
@@ -144,7 +145,7 @@ class CharacterProperties(Serialisable):
     sym = Typed(expected_type=Font, allow_none=True)
     hlinkClick = Typed(expected_type=Hyperlink, allow_none=True)
     hlinkMouseOver = Typed(expected_type=Hyperlink, allow_none=True)
-    rtl = Bool(nested=True, allow_none=True)
+    rtl = NestedBool(allow_none=True)
     extLst = Typed(expected_type=OfficeArtExtensionList, allow_none=True)
     # uses element group EG_FillProperties
     noFill = EmptyTag(namespace=DRAWING_NS)
